=== modified file 'plugin/pbms/src/defs_ms.h'
--- plugin/pbms/src/defs_ms.h	2010-10-18 21:21:20 +0000
+++ plugin/pbms/src/defs_ms.h	2010-11-07 05:11:55 +0000
@@ -146,6 +146,7 @@
 #define MYSQL_PLUGIN_VAR_HEADER				DRIZZLE_PLUGIN_VAR_HEADER
 #define MYSQL_SYSVAR_STR					DRIZZLE_SYSVAR_STR
 #define MYSQL_SYSVAR_INT					DRIZZLE_SYSVAR_INT
+#define MYSQL_SYSVAR_UINT					DRIZZLE_SYSVAR_UINT
 #define MYSQL_SYSVAR						DRIZZLE_SYSVAR
 #define MYSQL_SYSVAR_ULONG					DRIZZLE_SYSVAR_ULONG
 #define MYSQL_SYSVAR_ULONGLONG				DRIZZLE_SYSVAR_ULONGLONG

=== modified file 'plugin/pbms/src/parameters_ms.cc'
--- plugin/pbms/src/parameters_ms.cc	2010-10-18 21:21:20 +0000
+++ plugin/pbms/src/parameters_ms.cc	2010-11-07 05:11:55 +0000
@@ -64,7 +64,7 @@
 #endif
 
 
-static int my_port_number = PBMS_PORT;
+uint32_t pbms_port_number = PBMS_PORT;
 
 static char		*my_repository_threshold = NULL;
 static char		*my_temp_log_threshold = NULL;
@@ -123,7 +123,7 @@
 #endif
 
 //--------------
-uint32_t PBMSParameters::getPortNumber(){ return my_port_number;}
+uint32_t PBMSParameters::getPortNumber(){ return pbms_port_number;}
 
 //--------------
 uint32_t PBMSParameters::getServerID(){ return my_server_id;}
@@ -487,8 +487,8 @@
 
 //-----------------
 //-----------------
-static MYSQL_SYSVAR_INT(port, my_port_number,
-	PLUGIN_VAR_OPCMDARG | PLUGIN_VAR_READONLY,
+static MYSQL_SYSVAR_UINT(port, pbms_port_number,
+	PLUGIN_VAR_READONLY,
 	"The port for the server stream-based communications.",
 	NULL, NULL, PBMS_PORT, 0, 64*1024, 1);
 

=== modified file 'plugin/pbms/src/plugin_ms.cc'
--- plugin/pbms/src/plugin_ms.cc	2010-10-02 21:15:42 +0000
+++ plugin/pbms/src/plugin_ms.cc	2010-11-07 05:11:55 +0000
@@ -28,8 +28,11 @@
 #include <drizzled/common.h>
 #include <drizzled/plugin.h>
 #include <drizzled/session.h>
+#include <boost/program_options.hpp>
+#include <drizzled/module/option_map.h>
 using namespace drizzled;
 using namespace drizzled::plugin;
+namespace po= boost::program_options;
 
 #include "cslib/CSConfig.h"
 #else
@@ -45,7 +48,7 @@
 
 
 #include "defs_ms.h"
-
+#include "pbmslib.h"
 
 /////////////////////////
 // Plugin Definition:
@@ -58,17 +61,37 @@
 extern int pbms_init_func(module::Context &registry);
 extern struct drizzled::drizzle_sys_var* pbms_system_variables[];
 
-static int my_init(module::Context &registry)
+extern uint32_t pbms_port_number;
+
+static void init_options(drizzled::module::option_context &context)
+{
+  context("port",
+          po::value<uint32_t>(&pbms_port_number)->default_value(DEFAULT_PBMS_PORT),
+          N_("Port number to use for connection or 0 for default PBMS port "));
+}
+
+
+static int my_init(module::Context &context)
 {
 	int rtc;
-	
+        const module::option_map &vm= context.getOptions();
+
+        if (vm.count("port"))
+        {
+          if (pbms_port_number > 65535)
+          {
+            errmsg_printf(ERRMSG_LVL_ERROR, _("Invalid port number\n"));
+            return(-1);
+          }
+        }
+
 	PBMSParameters::startUp();
-	rtc = pbms_init_func(registry);
+	rtc = pbms_init_func(context);
 	if (rtc == 0) {
 		pbms_events = new PBMSEvents();
-		registry.add(pbms_events);
+		context.add(pbms_events);
 	}
-	
+
 	return rtc;
 }
 
@@ -82,7 +105,7 @@
 	PLUGIN_LICENSE_GPL,
 	my_init, /* Plugin Init */
 	pbms_system_variables,          /* system variables                */
-	NULL                                            /* config options                  */
+	init_options                                            /* config options                  */
 }
 DRIZZLE_DECLARE_PLUGIN_END;
 

=== modified file 'plugin/pbms/tests/t/master.opt'
--- plugin/pbms/tests/t/master.opt	2010-11-07 04:46:37 +0000
+++ plugin/pbms/tests/t/master.opt	2010-11-07 05:11:55 +0000
@@ -1,1 +1,1 @@
---plugin-add=pbms
+--plugin-add=pbms --pbms.port=$PBMS_PORT

